set terminal fig monochrome textspecial
set output "plot/transloss.fig" 

set title "Transmission loss as a function of frequency"
set xlabel "Frequency $f$ [Hz]"
set ylabel "Transmission Loss $TL_r$ [dB]" 

# Stops plotting at end of data, not continuing to next xtic or x2tic (x=7000):
set autoscale xfixmax;  set autoscale x2fixmax

# This loads the file containing the coincidence frequency, fc, which is around 2600 Hz.
# The file contains just "fc = 2603" or something like that.
load "data/transloss-fc.dat"

# Add a xtic and x2tic item for the coincidence frequency:
set xtics add ("$fc$" fc);              set x2tics add ("$fc$" fc)
set y2tics         # Set tics on right y-axis.

# Place legend at right bottom and increase spacing between items:
set key right bottom spacing 2.5

set grid           # enable grid, default settings

# Plotting with lines and specified linewidth (lw) = 3:
plot "data/transloss.dat" using 1:2 title "$20\\log(\\omega m)-48$" with lines lw 3, \
   "data/transloss.dat" using 1:3 title "$10\\log(1+\\frac{\\omega m}{2\\rho c}^2)-\
   10\\log(0.23\\cdot 10\\log(1+\\frac{\\omega m}{2\\rho c}^2))$"\
   with lines lw 3, \
"data/transloss-tab.dat" title "From table \\ref{tab:transloss}" with lines lw 3